CECI: CECI is a function to compute the Clark and Evans'...

View source: R/Linda.R

CECIR Documentation

CECI is a function to compute the Clark and Evans' competition index

Description

CECI is a function to compute the Clark and Evans' competition index, it computes the first nearest neighbor distance for all the spatial points using extensive two-dimensional circular area searching method.

Usage

CECI(xy, area = NULL, method = "NP")

Arguments

xy

xy is a two-column matrix, containing x and y coordinates of recorded organisms in a single line transect

area

area is the size of given study area, the default is NULL and will be estimated from xy data.

method

method is the method to compute the index, "NP" is the default, indicating the loop-way computation; "P" indicates parallel computing.

Value

It returns the following quantities:

R

the Clark and Evans' ratio value, which is the average of the observed NND versus the expected NND

t1

the average of the observed NND for all distributional points

t2

the expected NND under the perfect regularity pattern, details can be referred to Clark and Evans (1954).

c

the Z score value for testing significance

p

the p value for testing significance

Author(s)

Tsung-Jen Shen & Youhua Chen

References

Clark P, Evans F (1954) Distance to nearest neighbor as a measure of spatial relationships in populations. Ecology, 35, 445–453.

See Also

NND LNND

Examples

xy=cbind(runif(100),runif(100))
plot(xy)
CECI(xy)

Linda documentation built on July 4, 2026, 9:07 a.m.