| Linda-package | R Documentation |
Linda-an R package for conducting (Lin)e transect-based nearest neighbor (d)istance (a)nalysis
Linda is an R package for calculating one-dimensional nearest neighbor distance (NND) and conducting hypothesis testing related to local distributional aggregation pattern of species. The reason that such a package is needed is because traditional two-dimensional NND is not applicable when biodiversity data are sampled via optimal ecological survey methods, like line transects. In comparison to the entire studied region, line transect-collected local biodiversity data are spatially constrained and sampling-limited. To this end, two-dimensional NND would tend to over-estimate distributional aggregation pattern of species when using this limited biodiversity information. Accordingly, one-dimensional NND is needed and the associated statistical testing should be established for analyzing line transect-derived biodiversity data. Our package, Linda, is developed to fulfill this biodiversity-inference task.
Youhua Chen (Chengdu Institute of Biology, Chinese Academy of Sciences);
Maintainer:
Youhua Chen <chenyh@cib.ac.cn>
Xiaoqin Shi, Yongbin Wu, Qi Xiao, Youhua Chen (2026) Linda: an R package using Line transect-based nearest neighbor distance analysis to infer distributional aggregation pattern of species. Plant Diversity.
x=cbind(1,runif(100))
x=rbind(x,cbind(2,runif(100)))
x=rbind(x,cbind(3,runif(100)))
lxy=cbind(x,1)
lxy[,2]=sort(lxy[,2]) #sequentially sampled in an economic way
LNND(lxy)
#in empirical data, because we assume individuals have been recorded in sequential order
#so the original data do not need to be sorted.
#By contrast, in simulated data, if we assumed individuals are recorded in sequential order
#and in an economic way
#sort() function should be used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.