v.est: conspecific-encounter index for line transect-collecte...

View source: R/Linda.R

v.estR Documentation

conspecific-encounter index for line transect-collecte biodiversity data

Description

this is the line transect-derived conspecific encounter index, which is also the estimator of pi by Solow (2000). Note that conspecific-encounter index for line transect sampling is completely different to the conventional Simpson diversity index, which is proposed as a conspecific-encounter index under random sampling.

Usage

v.est(z)

Arguments

z

z is a vector of species labels for sequentially sampled individuals when walking across a line transect

Details

suppose we collect five individuals of three species along a line transect in sequential oder as "ABCAA", then the vector z=c("A","B","C","A","A")

Value

the conspecific-encounter index value is returned, and this value is bounded between 0 and 1.

Note

in empirical data provided by the users themselves, because we assume individuals have been recorded in the vector z in a sequential order, so the original dataset z do not need to be sorted and just be used as input directly.

Author(s)

Youhua Chen & Tsung-Jen Shen

References

Chen et al. (2019) Inferring multispecies distributional aggregation level from limited line transect-derived biodiversity data. Methods in Ecology and Evolution, 10, 1015-1023. Solow A (2000) The effect of dependence on estimating sample coverage. Environmetrics, 11, 245-249.

See Also

NND LNND pi.est

Examples

z=sample(1:5,100,replace=TRUE)
v.est(z)

Linda documentation built on July 4, 2026, 9:07 a.m.