| CECI | R Documentation |
CECI is a function to compute the Clark and Evans' competition index, it computes the first nearest neighbor distance for all the spatial points using extensive two-dimensional circular area searching method.
CECI(xy, area = NULL, method = "NP")
xy |
xy is a two-column matrix, containing x and y coordinates of recorded organisms in a single line transect |
area |
area is the size of given study area, the default is NULL and will be estimated from xy data. |
method |
method is the method to compute the index, "NP" is the default, indicating the loop-way computation; "P" indicates parallel computing. |
It returns the following quantities:
R |
the Clark and Evans' ratio value, which is the average of the observed NND versus the expected NND |
t1 |
the average of the observed NND for all distributional points |
t2 |
the expected NND under the perfect regularity pattern, details can be referred to Clark and Evans (1954). |
c |
the Z score value for testing significance |
p |
the p value for testing significance |
Tsung-Jen Shen & Youhua Chen
Clark P, Evans F (1954) Distance to nearest neighbor as a measure of spatial relationships in populations. Ecology, 35, 445–453.
NND
LNND
xy=cbind(runif(100),runif(100))
plot(xy)
CECI(xy)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.