| pi.est | R Documentation |
estimation of the inertia parameter pi, more details can be referred to Chen et al. (2023). This parameter has been closely related to Moran's I index, more details can be referred to Chen and Shen (2020).
pi.est(z)
z |
z is a vector of species labels for sequentially sampled individuals when walking across a line transect |
suppose we collect five individuals of three species along a line transect in sequential oder as "ABCAA", then the vector z=c("A","B","C","A","A")
the estimation of the inertia parameter is returned, and this value is bounded between 0 and 1.
in empirical data provided by the users themselves, because we assume individuals have been recorded in the vector z in a sequential order, so the original dataset z do not need to be sorted and just be used as input directly.
Tsung-Jen Shen
Chen et al. (2023) Biodiversity survey and estimation for line-transect sampling. Frontiers in Plant Science, 14: 1159090. Chen and Shen (2020) Unifying conspecific-encounter index v and Morans' I index. Ecography, 43, 1902-1904.
NND
LNND
v.est
z=sample(1:5,100,replace=TRUE)
pi.est(z)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.