| v.est | R Documentation |
this is the line transect-derived conspecific encounter index, which is also the estimator of pi by Solow (2000). Note that conspecific-encounter index for line transect sampling is completely different to the conventional Simpson diversity index, which is proposed as a conspecific-encounter index under random sampling.
v.est(z)
z |
z is a vector of species labels for sequentially sampled individuals when walking across a line transect |
suppose we collect five individuals of three species along a line transect in sequential oder as "ABCAA", then the vector z=c("A","B","C","A","A")
the conspecific-encounter index value is returned, and this value is bounded between 0 and 1.
in empirical data provided by the users themselves, because we assume individuals have been recorded in the vector z in a sequential order, so the original dataset z do not need to be sorted and just be used as input directly.
Youhua Chen & Tsung-Jen Shen
Chen et al. (2019) Inferring multispecies distributional aggregation level from limited line transect-derived biodiversity data. Methods in Ecology and Evolution, 10, 1015-1023. Solow A (2000) The effect of dependence on estimating sample coverage. Environmetrics, 11, 245-249.
NND
LNND
pi.est
z=sample(1:5,100,replace=TRUE)
v.est(z)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.